Forward Models (``taurex.model``)
==================================

Base
-------------------------

.. automodule:: taurex.model.model
   :members:
   :undoc-members:
   :show-inheritance:

Basic Model
-------------------------------

.. automodule:: taurex.model.simplemodel
   :members:
   :undoc-members:
   :show-inheritance:

Transmission
--------------------------------

.. automodule:: taurex.model.transmission
   :members:
   :undoc-members:
   :show-inheritance:

Emission
----------------------------

.. automodule:: taurex.model.emission
   :members:
   :undoc-members:
   :show-inheritance:

Direct Image
-------------------------------

.. automodule:: taurex.model.directimage
   :members:
   :undoc-members:
   :show-inheritance:


